# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/instances/instances.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/instances/instances.proto',
  package='yamcs.protobuf.instances',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\016InstancesProtoP\001',
  serialized_pb=b'\n(yamcs/protobuf/instances/instances.proto\x12\x18yamcs.protobuf.instances\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\"\xf7\x05\n\rYamcsInstance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12<\n\x0fmissionDatabase\x18\x03 \x01(\x0b\x32#.yamcs.protobuf.mdb.MissionDatabase\x12\x41\n\nprocessors\x18\x04 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\x12\x44\n\x05state\x18\x0b \x01(\x0e\x32\x35.yamcs.protobuf.instances.YamcsInstance.InstanceState\x12\x14\n\x0c\x66\x61ilureCause\x18\t \x01(\t\x12/\n\x0bmissionTime\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x06labels\x18\x0c \x03(\x0b\x32\x33.yamcs.protobuf.instances.YamcsInstance.LabelsEntry\x12\x14\n\x0c\x63\x61pabilities\x18\r \x03(\t\x12\x10\n\x08template\x18\x0e \x01(\t\x12O\n\x0ctemplateArgs\x18\x0f \x03(\x0b\x32\x39.yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry\x12\x19\n\x11templateAvailable\x18\x10 \x01(\x08\x12\x17\n\x0ftemplateChanged\x18\x11 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11TemplateArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\rInstanceState\x12\x0b\n\x07OFFLINE\x10\x00\x12\x10\n\x0cINITIALIZING\x10\x01\x12\x0f\n\x0bINITIALIZED\x10\x02\x12\x0c\n\x08STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\n\n\x06\x46\x41ILED\x10\x06\"t\n\x10InstanceTemplate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12=\n\tvariables\x18\x02 \x03(\x0b\x32*.yamcs.protobuf.instances.TemplateVariable\"\x7f\n\x10TemplateVariable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05label\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0c\n\x04help\x18\x02 \x01(\t\x12\x10\n\x08required\x18\x03 \x01(\x08\x12\x0f\n\x07\x63hoices\x18\x05 \x03(\t\x12\x0f\n\x07initial\x18\x07 \x01(\tB&\n\x12org.yamcs.protobufB\x0eInstancesProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,])



_YAMCSINSTANCE_INSTANCESTATE = _descriptor.EnumDescriptor(
  name='InstanceState',
  full_name='yamcs.protobuf.instances.YamcsInstance.InstanceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFFLINE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=831,
  serialized_end=947,
)
_sym_db.RegisterEnumDescriptor(_YAMCSINSTANCE_INSTANCESTATE)


_YAMCSINSTANCE_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yamcs.protobuf.instances.YamcsInstance.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.YamcsInstance.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.YamcsInstance.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=776,
)

_YAMCSINSTANCE_TEMPLATEARGSENTRY = _descriptor.Descriptor(
  name='TemplateArgsEntry',
  full_name='yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=829,
)

_YAMCSINSTANCE = _descriptor.Descriptor(
  name='YamcsInstance',
  full_name='yamcs.protobuf.instances.YamcsInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.instances.YamcsInstance.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missionDatabase', full_name='yamcs.protobuf.instances.YamcsInstance.missionDatabase', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processors', full_name='yamcs.protobuf.instances.YamcsInstance.processors', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.instances.YamcsInstance.state', index=3,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureCause', full_name='yamcs.protobuf.instances.YamcsInstance.failureCause', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='missionTime', full_name='yamcs.protobuf.instances.YamcsInstance.missionTime', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yamcs.protobuf.instances.YamcsInstance.labels', index=6,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='yamcs.protobuf.instances.YamcsInstance.capabilities', index=7,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='yamcs.protobuf.instances.YamcsInstance.template', index=8,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateArgs', full_name='yamcs.protobuf.instances.YamcsInstance.templateArgs', index=9,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateAvailable', full_name='yamcs.protobuf.instances.YamcsInstance.templateAvailable', index=10,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='templateChanged', full_name='yamcs.protobuf.instances.YamcsInstance.templateChanged', index=11,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_YAMCSINSTANCE_LABELSENTRY, _YAMCSINSTANCE_TEMPLATEARGSENTRY, ],
  enum_types=[
    _YAMCSINSTANCE_INSTANCESTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=947,
)


_INSTANCETEMPLATE = _descriptor.Descriptor(
  name='InstanceTemplate',
  full_name='yamcs.protobuf.instances.InstanceTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.instances.InstanceTemplate.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.instances.InstanceTemplate.description', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variables', full_name='yamcs.protobuf.instances.InstanceTemplate.variables', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=949,
  serialized_end=1065,
)


_TEMPLATEVARIABLE = _descriptor.Descriptor(
  name='TemplateVariable',
  full_name='yamcs.protobuf.instances.TemplateVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.instances.TemplateVariable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.instances.TemplateVariable.label', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.instances.TemplateVariable.type', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='help', full_name='yamcs.protobuf.instances.TemplateVariable.help', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required', full_name='yamcs.protobuf.instances.TemplateVariable.required', index=4,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='choices', full_name='yamcs.protobuf.instances.TemplateVariable.choices', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial', full_name='yamcs.protobuf.instances.TemplateVariable.initial', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1067,
  serialized_end=1194,
)

_YAMCSINSTANCE_LABELSENTRY.containing_type = _YAMCSINSTANCE
_YAMCSINSTANCE_TEMPLATEARGSENTRY.containing_type = _YAMCSINSTANCE
_YAMCSINSTANCE.fields_by_name['missionDatabase'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._MISSIONDATABASE
_YAMCSINSTANCE.fields_by_name['processors'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_YAMCSINSTANCE.fields_by_name['state'].enum_type = _YAMCSINSTANCE_INSTANCESTATE
_YAMCSINSTANCE.fields_by_name['missionTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_YAMCSINSTANCE.fields_by_name['labels'].message_type = _YAMCSINSTANCE_LABELSENTRY
_YAMCSINSTANCE.fields_by_name['templateArgs'].message_type = _YAMCSINSTANCE_TEMPLATEARGSENTRY
_YAMCSINSTANCE_INSTANCESTATE.containing_type = _YAMCSINSTANCE
_INSTANCETEMPLATE.fields_by_name['variables'].message_type = _TEMPLATEVARIABLE
DESCRIPTOR.message_types_by_name['YamcsInstance'] = _YAMCSINSTANCE
DESCRIPTOR.message_types_by_name['InstanceTemplate'] = _INSTANCETEMPLATE
DESCRIPTOR.message_types_by_name['TemplateVariable'] = _TEMPLATEVARIABLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YamcsInstance = _reflection.GeneratedProtocolMessageType('YamcsInstance', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _YAMCSINSTANCE_LABELSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.YamcsInstance.LabelsEntry)
    })
  ,

  'TemplateArgsEntry' : _reflection.GeneratedProtocolMessageType('TemplateArgsEntry', (_message.Message,), {
    'DESCRIPTOR' : _YAMCSINSTANCE_TEMPLATEARGSENTRY,
    '__module__' : 'yamcs.protobuf.instances.instances_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.YamcsInstance.TemplateArgsEntry)
    })
  ,
  'DESCRIPTOR' : _YAMCSINSTANCE,
  '__module__' : 'yamcs.protobuf.instances.instances_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.YamcsInstance)
  })
_sym_db.RegisterMessage(YamcsInstance)
_sym_db.RegisterMessage(YamcsInstance.LabelsEntry)
_sym_db.RegisterMessage(YamcsInstance.TemplateArgsEntry)

InstanceTemplate = _reflection.GeneratedProtocolMessageType('InstanceTemplate', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCETEMPLATE,
  '__module__' : 'yamcs.protobuf.instances.instances_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.InstanceTemplate)
  })
_sym_db.RegisterMessage(InstanceTemplate)

TemplateVariable = _reflection.GeneratedProtocolMessageType('TemplateVariable', (_message.Message,), {
  'DESCRIPTOR' : _TEMPLATEVARIABLE,
  '__module__' : 'yamcs.protobuf.instances.instances_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.instances.TemplateVariable)
  })
_sym_db.RegisterMessage(TemplateVariable)


DESCRIPTOR._options = None
_YAMCSINSTANCE_LABELSENTRY._options = None
_YAMCSINSTANCE_TEMPLATEARGSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/api/httpbody.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/api/httpbody.proto',
  package='yamcs.api',
  syntax='proto2',
  serialized_options=b'\n\rorg.yamcs.apiB\rHttpBodyProtoP\001',
  serialized_pb=b'\n\x18yamcs/api/httpbody.proto\x12\tyamcs.api\"\xa6\x01\n\x08HttpBody\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x33\n\x08metadata\x18\x04 \x03(\x0b\x32!.yamcs.api.HttpBody.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42 \n\rorg.yamcs.apiB\rHttpBodyProtoP\x01'
)




_HTTPBODY_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yamcs.api.HttpBody.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.api.HttpBody.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.api.HttpBody.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=206,
)

_HTTPBODY = _descriptor.Descriptor(
  name='HttpBody',
  full_name='yamcs.api.HttpBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_type', full_name='yamcs.api.HttpBody.content_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='yamcs.api.HttpBody.filename', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.api.HttpBody.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yamcs.api.HttpBody.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_HTTPBODY_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=206,
)

_HTTPBODY_METADATAENTRY.containing_type = _HTTPBODY
_HTTPBODY.fields_by_name['metadata'].message_type = _HTTPBODY_METADATAENTRY
DESCRIPTOR.message_types_by_name['HttpBody'] = _HTTPBODY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpBody = _reflection.GeneratedProtocolMessageType('HttpBody', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _HTTPBODY_METADATAENTRY,
    '__module__' : 'yamcs.api.httpbody_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.api.HttpBody.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _HTTPBODY,
  '__module__' : 'yamcs.api.httpbody_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.HttpBody)
  })
_sym_db.RegisterMessage(HttpBody)
_sym_db.RegisterMessage(HttpBody.MetadataEntry)


DESCRIPTOR._options = None
_HTTPBODY_METADATAENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/plists/plists.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/plists/plists.proto',
  package='yamcs.protobuf.plists',
  syntax='proto2',
  serialized_options=b'\n\031org.yamcs.protobuf.plistsB\023ParameterListsProtoP\001',
  serialized_pb=b'\n\"yamcs/protobuf/plists/plists.proto\x12\x15yamcs.protobuf.plists\x1a\x1cyamcs/protobuf/mdb/mdb.proto\"\x86\x01\n\x11ParameterListInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08patterns\x18\x04 \x03(\t\x12\x30\n\x05match\x18\x05 \x03(\x0b\x32!.yamcs.protobuf.mdb.ParameterInfoB2\n\x19org.yamcs.protobuf.plistsB\x13ParameterListsProtoP\x01'
  ,
  dependencies=[yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,])




_PARAMETERLISTINFO = _descriptor.Descriptor(
  name='ParameterListInfo',
  full_name='yamcs.protobuf.plists.ParameterListInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.plists.ParameterListInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.plists.ParameterListInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.plists.ParameterListInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='patterns', full_name='yamcs.protobuf.plists.ParameterListInfo.patterns', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match', full_name='yamcs.protobuf.plists.ParameterListInfo.match', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=226,
)

_PARAMETERLISTINFO.fields_by_name['match'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._PARAMETERINFO
DESCRIPTOR.message_types_by_name['ParameterListInfo'] = _PARAMETERLISTINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParameterListInfo = _reflection.GeneratedProtocolMessageType('ParameterListInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERLISTINFO,
  '__module__' : 'yamcs.protobuf.plists.plists_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.plists.ParameterListInfo)
  })
_sym_db.RegisterMessage(ParameterListInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/api/websocket.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from yamcs.api import exception_pb2 as yamcs_dot_api_dot_exception__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/api/websocket.proto',
  package='yamcs.api',
  syntax='proto3',
  serialized_options=b'\n\022org.yamcs.protobufB\016WebSocketProtoP\001',
  serialized_pb=b'\n\x19yamcs/api/websocket.proto\x12\tyamcs.api\x1a\x19google/protobuf/any.proto\x1a\x19yamcs/api/exception.proto\"\x91\x01\n\rClientMessage\x12\x0c\n\x04type\x18\x01 \x01(\t\x12%\n\x07options\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\n\n\x02id\x18\x03 \x01(\x05\x12\x0c\n\x04\x63\x61ll\x18\x04 \x01(\x05\x12\x1c\n\x10maxDroppedWrites\x18\x05 \x01(\x05\x42\x02\x18\x01\x12\x13\n\x0blowPriority\x18\x06 \x01(\x08\"\\\n\rServerMessage\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04\x63\x61ll\x18\x02 \x01(\x05\x12\x0b\n\x03seq\x18\x03 \x01(\x05\x12\"\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\x1d\n\rCancelOptions\x12\x0c\n\x04\x63\x61ll\x18\x01 \x01(\x05\"I\n\x05Reply\x12\x10\n\x08reply_to\x18\x01 \x01(\x05\x12.\n\texception\x18\x02 \x01(\x0b\x32\x1b.yamcs.api.ExceptionMessage\"\x80\x01\n\x05State\x12(\n\x05\x63\x61lls\x18\x01 \x03(\x0b\x32\x19.yamcs.api.State.CallInfo\x1aM\n\x08\x43\x61llInfo\x12\x0c\n\x04\x63\x61ll\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12%\n\x07options\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB&\n\x12org.yamcs.protobufB\x0eWebSocketProtoP\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,yamcs_dot_api_dot_exception__pb2.DESCRIPTOR,])




_CLIENTMESSAGE = _descriptor.Descriptor(
  name='ClientMessage',
  full_name='yamcs.api.ClientMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.api.ClientMessage.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='yamcs.api.ClientMessage.options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.api.ClientMessage.id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call', full_name='yamcs.api.ClientMessage.call', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxDroppedWrites', full_name='yamcs.api.ClientMessage.maxDroppedWrites', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lowPriority', full_name='yamcs.api.ClientMessage.lowPriority', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=240,
)


_SERVERMESSAGE = _descriptor.Descriptor(
  name='ServerMessage',
  full_name='yamcs.api.ServerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.api.ServerMessage.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call', full_name='yamcs.api.ServerMessage.call', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seq', full_name='yamcs.api.ServerMessage.seq', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.api.ServerMessage.data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=334,
)


_CANCELOPTIONS = _descriptor.Descriptor(
  name='CancelOptions',
  full_name='yamcs.api.CancelOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call', full_name='yamcs.api.CancelOptions.call', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=365,
)


_REPLY = _descriptor.Descriptor(
  name='Reply',
  full_name='yamcs.api.Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reply_to', full_name='yamcs.api.Reply.reply_to', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exception', full_name='yamcs.api.Reply.exception', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=440,
)


_STATE_CALLINFO = _descriptor.Descriptor(
  name='CallInfo',
  full_name='yamcs.api.State.CallInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call', full_name='yamcs.api.State.CallInfo.call', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.api.State.CallInfo.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='yamcs.api.State.CallInfo.options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=571,
)

_STATE = _descriptor.Descriptor(
  name='State',
  full_name='yamcs.api.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='calls', full_name='yamcs.api.State.calls', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATE_CALLINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=571,
)

_CLIENTMESSAGE.fields_by_name['options'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SERVERMESSAGE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_REPLY.fields_by_name['exception'].message_type = yamcs_dot_api_dot_exception__pb2._EXCEPTIONMESSAGE
_STATE_CALLINFO.fields_by_name['options'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATE_CALLINFO.containing_type = _STATE
_STATE.fields_by_name['calls'].message_type = _STATE_CALLINFO
DESCRIPTOR.message_types_by_name['ClientMessage'] = _CLIENTMESSAGE
DESCRIPTOR.message_types_by_name['ServerMessage'] = _SERVERMESSAGE
DESCRIPTOR.message_types_by_name['CancelOptions'] = _CANCELOPTIONS
DESCRIPTOR.message_types_by_name['Reply'] = _REPLY
DESCRIPTOR.message_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClientMessage = _reflection.GeneratedProtocolMessageType('ClientMessage', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTMESSAGE,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.ClientMessage)
  })
_sym_db.RegisterMessage(ClientMessage)

ServerMessage = _reflection.GeneratedProtocolMessageType('ServerMessage', (_message.Message,), {
  'DESCRIPTOR' : _SERVERMESSAGE,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.ServerMessage)
  })
_sym_db.RegisterMessage(ServerMessage)

CancelOptions = _reflection.GeneratedProtocolMessageType('CancelOptions', (_message.Message,), {
  'DESCRIPTOR' : _CANCELOPTIONS,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.CancelOptions)
  })
_sym_db.RegisterMessage(CancelOptions)

Reply = _reflection.GeneratedProtocolMessageType('Reply', (_message.Message,), {
  'DESCRIPTOR' : _REPLY,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.Reply)
  })
_sym_db.RegisterMessage(Reply)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

  'CallInfo' : _reflection.GeneratedProtocolMessageType('CallInfo', (_message.Message,), {
    'DESCRIPTOR' : _STATE_CALLINFO,
    '__module__' : 'yamcs.api.websocket_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.api.State.CallInfo)
    })
  ,
  'DESCRIPTOR' : _STATE,
  '__module__' : 'yamcs.api.websocket_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.api.State)
  })
_sym_db.RegisterMessage(State)
_sym_db.RegisterMessage(State.CallInfo)


DESCRIPTOR._options = None
_CLIENTMESSAGE.fields_by_name['maxDroppedWrites']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/services/services_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.services import services_pb2 as yamcs_dot_protobuf_dot_services_dot_services__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/services/services_service.proto',
  package='yamcs.protobuf.services',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\024ServicesServiceProtoP\001',
  serialized_pb=b'\n.yamcs/protobuf/services/services_service.proto\x12\x17yamcs.protobuf.services\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a&yamcs/protobuf/services/services.proto\"\'\n\x13ListServicesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"3\n\x11GetServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x13StartServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"4\n\x12StopServiceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x14ListServicesResponse\x12\x36\n\x08services\x18\x01 \x03(\x0b\x32$.yamcs.protobuf.services.ServiceInfo2\xa7\x04\n\x0bServicesApi\x12\x8b\x01\n\x0cListServices\x12,.yamcs.protobuf.services.ListServicesRequest\x1a-.yamcs.protobuf.services.ListServicesResponse\"\x1e\x8a\x92\x03\x1a\n\x18/api/services/{instance}\x12\x85\x01\n\nGetService\x12*.yamcs.protobuf.services.GetServiceRequest\x1a$.yamcs.protobuf.services.ServiceInfo\"%\x8a\x92\x03!\n\x1f/api/services/{instance}/{name}\x12\x81\x01\n\x0cStartService\x12,.yamcs.protobuf.services.StartServiceRequest\x1a\x16.google.protobuf.Empty\"+\x8a\x92\x03\'\x1a%/api/services/{instance}/{name}:start\x12~\n\x0bStopService\x12+.yamcs.protobuf.services.StopServiceRequest\x1a\x16.google.protobuf.Empty\"*\x8a\x92\x03&\x1a$/api/services/{instance}/{name}:stopB,\n\x12org.yamcs.protobufB\x14ServicesServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_services_dot_services__pb2.DESCRIPTOR,])




_LISTSERVICESREQUEST = _descriptor.Descriptor(
  name='ListServicesRequest',
  full_name='yamcs.protobuf.services.ListServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.ListServicesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=212,
)


_GETSERVICEREQUEST = _descriptor.Descriptor(
  name='GetServiceRequest',
  full_name='yamcs.protobuf.services.GetServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.GetServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.services.GetServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=265,
)


_STARTSERVICEREQUEST = _descriptor.Descriptor(
  name='StartServiceRequest',
  full_name='yamcs.protobuf.services.StartServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.StartServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.services.StartServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=320,
)


_STOPSERVICEREQUEST = _descriptor.Descriptor(
  name='StopServiceRequest',
  full_name='yamcs.protobuf.services.StopServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.StopServiceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.services.StopServiceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=374,
)


_LISTSERVICESRESPONSE = _descriptor.Descriptor(
  name='ListServicesResponse',
  full_name='yamcs.protobuf.services.ListServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='yamcs.protobuf.services.ListServicesResponse.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=454,
)

_LISTSERVICESRESPONSE.fields_by_name['services'].message_type = yamcs_dot_protobuf_dot_services_dot_services__pb2._SERVICEINFO
DESCRIPTOR.message_types_by_name['ListServicesRequest'] = _LISTSERVICESREQUEST
DESCRIPTOR.message_types_by_name['GetServiceRequest'] = _GETSERVICEREQUEST
DESCRIPTOR.message_types_by_name['StartServiceRequest'] = _STARTSERVICEREQUEST
DESCRIPTOR.message_types_by_name['StopServiceRequest'] = _STOPSERVICEREQUEST
DESCRIPTOR.message_types_by_name['ListServicesResponse'] = _LISTSERVICESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListServicesRequest = _reflection.GeneratedProtocolMessageType('ListServicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESREQUEST,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.ListServicesRequest)
  })
_sym_db.RegisterMessage(ListServicesRequest)

GetServiceRequest = _reflection.GeneratedProtocolMessageType('GetServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.GetServiceRequest)
  })
_sym_db.RegisterMessage(GetServiceRequest)

StartServiceRequest = _reflection.GeneratedProtocolMessageType('StartServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.StartServiceRequest)
  })
_sym_db.RegisterMessage(StartServiceRequest)

StopServiceRequest = _reflection.GeneratedProtocolMessageType('StopServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPSERVICEREQUEST,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.StopServiceRequest)
  })
_sym_db.RegisterMessage(StopServiceRequest)

ListServicesResponse = _reflection.GeneratedProtocolMessageType('ListServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESPONSE,
  '__module__' : 'yamcs.protobuf.services.services_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.ListServicesResponse)
  })
_sym_db.RegisterMessage(ListServicesResponse)


DESCRIPTOR._options = None

_SERVICESAPI = _descriptor.ServiceDescriptor(
  name='ServicesApi',
  full_name='yamcs.protobuf.services.ServicesApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=457,
  serialized_end=1008,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListServices',
    full_name='yamcs.protobuf.services.ServicesApi.ListServices',
    index=0,
    containing_service=None,
    input_type=_LISTSERVICESREQUEST,
    output_type=_LISTSERVICESRESPONSE,
    serialized_options=b'\212\222\003\032\n\030/api/services/{instance}',
  ),
  _descriptor.MethodDescriptor(
    name='GetService',
    full_name='yamcs.protobuf.services.ServicesApi.GetService',
    index=1,
    containing_service=None,
    input_type=_GETSERVICEREQUEST,
    output_type=yamcs_dot_protobuf_dot_services_dot_services__pb2._SERVICEINFO,
    serialized_options=b'\212\222\003!\n\037/api/services/{instance}/{name}',
  ),
  _descriptor.MethodDescriptor(
    name='StartService',
    full_name='yamcs.protobuf.services.ServicesApi.StartService',
    index=2,
    containing_service=None,
    input_type=_STARTSERVICEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003\'\032%/api/services/{instance}/{name}:start',
  ),
  _descriptor.MethodDescriptor(
    name='StopService',
    full_name='yamcs.protobuf.services.ServicesApi.StopService',
    index=3,
    containing_service=None,
    input_type=_STOPSERVICEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003&\032$/api/services/{instance}/{name}:stop',
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVICESAPI)

DESCRIPTOR.services_by_name['ServicesApi'] = _SERVICESAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/clearance_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/clearance_service.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\025ClearanceServiceProtoP\001',
  serialized_pb=b'\n1yamcs/protobuf/commanding/clearance_service.proto\x12\x19yamcs.protobuf.commanding\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\"V\n\x16ListClearancesResponse\x12<\n\nclearances\x18\x01 \x03(\x0b\x32(.yamcs.protobuf.commanding.ClearanceInfo\"\xcb\x01\n\rClearanceInfo\x12\x10\n\x08username\x18\x01 \x01(\t\x12I\n\x05level\x18\x02 \x01(\x0e\x32:.yamcs.protobuf.mdb.SignificanceInfo.SignificanceLevelType\x12\x10\n\x08issuedBy\x18\x03 \x01(\t\x12-\n\tissueTime\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14hasCommandPrivileges\x18\x05 \x01(\x08\"u\n\x16UpdateClearanceRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12I\n\x05level\x18\x02 \x01(\x0e\x32:.yamcs.protobuf.mdb.SignificanceInfo.SignificanceLevelType\"*\n\x16\x44\x65leteClearanceRequest\x12\x10\n\x08username\x18\x01 \x01(\t2\xdc\x04\n\x0c\x43learanceApi\x12r\n\x0eListClearances\x12\x16.google.protobuf.Empty\x1a\x31.yamcs.protobuf.commanding.ListClearancesResponse\"\x15\x8a\x92\x03\x11\n\x0f/api/clearances\x12\xc1\x01\n\x0fUpdateClearance\x12\x31.yamcs.protobuf.commanding.UpdateClearanceRequest\x1a(.yamcs.protobuf.commanding.ClearanceInfo\"Q\x8a\x92\x03M*\x1a/api/clearances/{username}:\x01*b,Clearance of \'{username}\' changed to {level}\x12\xa8\x01\n\x0f\x44\x65leteClearance\x12\x31.yamcs.protobuf.commanding.DeleteClearanceRequest\x1a\x16.google.protobuf.Empty\"J\x8a\x92\x03\x46\"\x1a/api/clearances/{username}b(Clearance revoked from user \'{username}\'\x12i\n\x12SubscribeClearance\x12\x16.google.protobuf.Empty\x1a(.yamcs.protobuf.commanding.ClearanceInfo\"\x0f\xda\x92\x03\x0b\n\tclearance0\x01\x42-\n\x12org.yamcs.protobufB\x15\x43learanceServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,])




_LISTCLEARANCESRESPONSE = _descriptor.Descriptor(
  name='ListClearancesResponse',
  full_name='yamcs.protobuf.commanding.ListClearancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clearances', full_name='yamcs.protobuf.commanding.ListClearancesResponse.clearances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=287,
)


_CLEARANCEINFO = _descriptor.Descriptor(
  name='ClearanceInfo',
  full_name='yamcs.protobuf.commanding.ClearanceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.commanding.ClearanceInfo.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='yamcs.protobuf.commanding.ClearanceInfo.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issuedBy', full_name='yamcs.protobuf.commanding.ClearanceInfo.issuedBy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issueTime', full_name='yamcs.protobuf.commanding.ClearanceInfo.issueTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasCommandPrivileges', full_name='yamcs.protobuf.commanding.ClearanceInfo.hasCommandPrivileges', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=493,
)


_UPDATECLEARANCEREQUEST = _descriptor.Descriptor(
  name='UpdateClearanceRequest',
  full_name='yamcs.protobuf.commanding.UpdateClearanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.commanding.UpdateClearanceRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='yamcs.protobuf.commanding.UpdateClearanceRequest.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=495,
  serialized_end=612,
)


_DELETECLEARANCEREQUEST = _descriptor.Descriptor(
  name='DeleteClearanceRequest',
  full_name='yamcs.protobuf.commanding.DeleteClearanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.commanding.DeleteClearanceRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=656,
)

_LISTCLEARANCESRESPONSE.fields_by_name['clearances'].message_type = _CLEARANCEINFO
_CLEARANCEINFO.fields_by_name['level'].enum_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE
_CLEARANCEINFO.fields_by_name['issueTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPDATECLEARANCEREQUEST.fields_by_name['level'].enum_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._SIGNIFICANCEINFO_SIGNIFICANCELEVELTYPE
DESCRIPTOR.message_types_by_name['ListClearancesResponse'] = _LISTCLEARANCESRESPONSE
DESCRIPTOR.message_types_by_name['ClearanceInfo'] = _CLEARANCEINFO
DESCRIPTOR.message_types_by_name['UpdateClearanceRequest'] = _UPDATECLEARANCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteClearanceRequest'] = _DELETECLEARANCEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListClearancesResponse = _reflection.GeneratedProtocolMessageType('ListClearancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLEARANCESRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.clearance_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListClearancesResponse)
  })
_sym_db.RegisterMessage(ListClearancesResponse)

ClearanceInfo = _reflection.GeneratedProtocolMessageType('ClearanceInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLEARANCEINFO,
  '__module__' : 'yamcs.protobuf.commanding.clearance_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ClearanceInfo)
  })
_sym_db.RegisterMessage(ClearanceInfo)

UpdateClearanceRequest = _reflection.GeneratedProtocolMessageType('UpdateClearanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLEARANCEREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.clearance_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.UpdateClearanceRequest)
  })
_sym_db.RegisterMessage(UpdateClearanceRequest)

DeleteClearanceRequest = _reflection.GeneratedProtocolMessageType('DeleteClearanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECLEARANCEREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.clearance_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.DeleteClearanceRequest)
  })
_sym_db.RegisterMessage(DeleteClearanceRequest)


DESCRIPTOR._options = None

_CLEARANCEAPI = _descriptor.ServiceDescriptor(
  name='ClearanceApi',
  full_name='yamcs.protobuf.commanding.ClearanceApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=659,
  serialized_end=1263,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListClearances',
    full_name='yamcs.protobuf.commanding.ClearanceApi.ListClearances',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTCLEARANCESRESPONSE,
    serialized_options=b'\212\222\003\021\n\017/api/clearances',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateClearance',
    full_name='yamcs.protobuf.commanding.ClearanceApi.UpdateClearance',
    index=1,
    containing_service=None,
    input_type=_UPDATECLEARANCEREQUEST,
    output_type=_CLEARANCEINFO,
    serialized_options=b'\212\222\003M*\032/api/clearances/{username}:\001*b,Clearance of \'{username}\' changed to {level}',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteClearance',
    full_name='yamcs.protobuf.commanding.ClearanceApi.DeleteClearance',
    index=2,
    containing_service=None,
    input_type=_DELETECLEARANCEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003F\"\032/api/clearances/{username}b(Clearance revoked from user \'{username}\'',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeClearance',
    full_name='yamcs.protobuf.commanding.ClearanceApi.SubscribeClearance',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_CLEARANCEINFO,
    serialized_options=b'\332\222\003\013\n\tclearance',
  ),
])
_sym_db.RegisterServiceDescriptor(_CLEARANCEAPI)

DESCRIPTOR.services_by_name['ClearanceApi'] = _CLEARANCEAPI

# @@protoc_insertion_point(module_scope)



import abc
from typing import Dict, List, Optional, Tuple

from yamcs.protobuf.mdb import mdb_pb2


class MissionDatabaseItem(abc.ABC):
    """
    Superclass for MDB items. Implementations:

    * :class:`.Algorithm`
    * :class:`.Command`
    * :class:`.Container`
    * :class:`.Parameter`
    * :class:`.ParameterType`
    * :class:`.SpaceSystem`
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self) -> str:
        """Short name"""
        return self._proto.name

    @property
    def qualified_name(self) -> str:
        """Full name (incl. space system)"""
        return self._proto.qualifiedName

    @property
    def aliases(self) -> Dict[str, str]:
        """Aliases, keyed by namespace"""
        return {alias.namespace: alias.name for alias in self._proto.alias}

    @property
    def aliases_dict(self) -> Dict[str, str]:
        """
        Aliases, keyed by namespace

        This method shall be deprecated in a future release. Use
        :attr:`aliases` instead.
        """
        return self.aliases

    @property
    def description(self) -> Optional[str]:
        """Short description."""
        if self._proto.HasField("shortDescription"):
            return self._proto.shortDescription
        return None

    @property
    def long_description(self) -> Optional[str]:
        """Long description."""
        if self._proto.HasField("longDescription"):
            return self._proto.longDescription
        return None

    def __str__(self):
        return self.qualified_name


class Algorithm(MissionDatabaseItem):
    def __init__(self, proto):
        super().__init__(proto)


class Command(MissionDatabaseItem):
    def __init__(self, proto):
        super().__init__(proto)

    @property
    def base_command(self) -> Optional["Command"]:
        if self._proto.HasField("baseCommand"):
            return Command(self._proto.baseCommand)
        return None

    @property
    def abstract(self) -> bool:
        """
        Whether this is an abstract command. Abstract commands are
        intended for inheritance and cannot be issued directly.
        """
        return self._proto.abstract

    @property
    def significance(self) -> Optional["Significance"]:
        if self._proto.HasField("significance"):
            return Significance(self._proto.significance)
        return None

    @property
    def arguments(self) -> List["Argument"]:
        return [Argument(pb) for pb in self._proto.argument]


class Argument:
    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self) -> str:
        """Argument name"""
        return self._proto.name

    @property
    def description(self) -> Optional[str]:
        """Short description"""
        if self._proto.HasField("description"):
            return self._proto.description
        return None

    @property
    def initial_value(self) -> Optional[str]:
        """Initial value"""
        if self._proto.HasField("initialValue"):
            return self._proto.initialValue
        return None

    @property
    def type(self) -> "ArgumentType":
        """Argument type information"""
        return ArgumentType(self._proto.type)

    def __str__(self):
        return self.name


class ArgumentType:
    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self) -> str:
        """Type name"""
        return self._proto.name

    @property
    def eng_type(self) -> str:
        """Engineering type"""
        return self._proto.engType

    def __str__(self):
        return self.name


class Container(MissionDatabaseItem):
    def __init__(self, proto):
        super().__init__(proto)


class Significance:
    def __init__(self, proto):
        self._proto = proto

    @property
    def consequence_level(self) -> str:
        """
        One of ``NONE``, ``WATCH``, ``WARNING``, ``DISTRESS``, ``CRITICAL``
        or ``SEVERE``.
        """
        return mdb_pb2.SignificanceInfo.SignificanceLevelType.Name(
            self._proto.consequenceLevel
        )

    @property
    def reason(self) -> Optional[str]:
        """Message attached to this significance."""
        if self._proto.HasField("reasonForWarning"):
            return self._proto.reasonForWarning
        return None

    def __str__(self):
        return f"[{self.consequence_level}] {self.reason}"


class ArrayType:
    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self) -> str:
        """Short name of this type."""
        return self._proto.type.engType

    @property
    def array_type(self) -> Optional["ArrayType"]:
        """
        In case the elements of an array of this type are also of type `array`, this
        returns type info of the elements' array type.

        .. note::
            This is an uncommon use case. Multi-dimensional arrays are more prevalent.
        """
        if self._proto.type.HasField("arrayInfo"):
            return ArrayType(self._proto.type.arrayInfo)
        return None

    @property
    def members(self) -> List["Member"]:
        """
        In case the elements of this array are of type `aggregate`, this returns
        an ordered list of its direct sub-members.
        """
        return [Member(member) for member in self._proto.type.member]

    @property
    def dimensions(self) -> Optional[int]:
        """The number of dimensions in case of a multi-dimensional array."""
        if self._proto.HasField("dimensions"):
            return self._proto.dimensions
        return None

    def __str__(self):
        return self.name


class Member:
    """
    A member is a data structure for a specific field of a parent data type
    (either another member, or a parameter of type `aggregate`).

    This is similar to C structs. The top-level of a member hierarchy is
    a parameter of type `aggregate`.
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def name(self) -> str:
        """Short name"""
        return self._proto.name

    @property
    def type(self) -> str:
        """Engineering type."""
        return self._proto.type.engType

    @property
    def array_type(self) -> Optional[ArrayType]:
        """
        In case this member is of type `array`, this returns array-specific
        type info.
        """
        if self._proto.type.HasField("arrayInfo"):
            return ArrayType(self._proto.type.arrayInfo)
        return None

    @property
    def members(self) -> List["Member"]:
        """
        In case this member is of type `aggregate`, this returns an ordered list
        of its direct sub-members.
        """
        return [Member(member) for member in self._proto.type.member]

    def __str__(self):
        return self.name


class EnumValue:
    def __init__(self, proto):
        self._proto = proto

    @property
    def value(self) -> int:
        """Numeric value"""
        return self._proto.value

    @property
    def label(self) -> str:
        """String value"""
        return self._proto.label

    @property
    def description(self) -> Optional[str]:
        """State description"""
        if self._proto.HasField("description"):
            return self.__proto.description
        return None

    def __str__(self):
        return self.label


class DataEncoding:
    def __init__(self, proto):
        self._proto = proto

    @property
    def type(self) -> str:
        """Raw type"""
        return mdb_pb2.DataEncodingInfo.Type.Name(self._proto.type)

    @property
    def little_endian(self) -> bool:
        """True if little-endian"""
        return self._proto.littleEndian

    @property
    def bitlength(self) -> Optional[int]:
        """The size in bits"""
        if self._proto.HasField("sizeInBits"):
            return self._proto.sizeInBits
        return None

    @property
    def encoding(self) -> Optional[str]:
        """Encoding detail"""
        if self._proto.HasField("encoding"):
            return self._proto.encoding
        return None

    def __str__(self):
        return self.type


class Parameter(MissionDatabaseItem):
    """
    A Parameter is a description of something that can have
    a value. It is not the value itself.
    """

    def __init__(self, proto):
        super().__init__(proto)

    @property
    def data_source(self) -> Optional[str]:
        """
        Specifies the source of this parameter (example: ``TELEMETERED``)
        """
        if self._proto.HasField("dataSource"):
            return mdb_pb2.DataSourceType.Name(self._proto.dataSource)
        return None

    @property
    def type(self) -> Optional[str]:
        """
        Engineering type.
        """
        if self._proto.type.HasField("engType"):
            return self._proto.type.engType
        return None

    @property
    def array_type(self) -> Optional[ArrayType]:
        """
        In case this parameter is of type `array`, this returns array-specific
        type info.
        """
        if self._proto.type.HasField("arrayInfo"):
            return ArrayType(self._proto.type.arrayInfo)
        return None

    @property
    def members(self) -> List[Member]:
        """
        In case this parameter is of type `aggregate`, this returns an ordered list
        of its direct members.
        """
        return [Member(member) for member in self._proto.type.member]

    @property
    def units(self) -> List[str]:
        """
        Engineering unit(s)
        """
        return [info.unit for info in self._proto.type.unitSet]

    @property
    def enum_values(self) -> List[EnumValue]:
        """
        In case this parameter is of type `enumeration`, this returns an ordered list
        of possible values.
        """
        return [EnumValue(enumValue) for enumValue in self._proto.type.enumValue]

    @property
    def data_encoding(self) -> Optional[DataEncoding]:
        """
        Information on the raw encoding of this parameter, if applicable.
        """
        if self._proto.type.HasField("dataEncoding"):
            return DataEncoding(self._proto.type.dataEncoding)
        return None


class ParameterType(MissionDatabaseItem):
    def __init__(self, proto):
        super().__init__(proto)

    @property
    def type(self) -> str:
        """
        Engineering type.
        """
        return self._proto.engType

    @property
    def array_type(self) -> Optional[ArrayType]:
        """
        In case this parameter type is of type `array`, this returns array-specific
        type info.
        """
        if self._proto.HasField("arrayInfo"):
            return ArrayType(self._proto.arrayInfo)
        return None

    @property
    def members(self) -> List[Member]:
        """
        In case this parameter type is of type `aggregate`, this returns an ordered list
        of its direct members.
        """
        return [Member(member) for member in self._proto.member]

    @property
    def units(self) -> List[str]:
        """
        Engineering unit(s)
        """
        return [info.unit for info in self._proto.unitSet]

    @property
    def enum_values(self) -> List[EnumValue]:
        """
        In case this parameter type is of type `enumeration`, this returns an ordered
        list of possible values.
        """
        return [EnumValue(enumValue) for enumValue in self._proto.enumValue]

    @property
    def data_encoding(self) -> Optional[DataEncoding]:
        """
        Information on the raw encoding of this parameter type, if applicable.
        """
        if self._proto.HasField("dataEncoding"):
            return DataEncoding(self._proto.dataEncoding)
        return None


class SpaceSystem(MissionDatabaseItem):
    """
    From XTCE:

        A SpaceSystem is a collection of SpaceSystem(s) including space assets,
        ground assets, multi-satellite systems and sub-systems.  A SpaceSystem
        is the root element for the set of data necessary to monitor and command
        an arbitrary space device - this includes the binary decomposition of
        the data streams going into and out of a device.
    """

    def __init__(self, proto):
        super().__init__(proto)


class RangeSet:
    """
    A set of alarm range that apply in a specific context.
    """

    # This is the same as yamcs.tmtc.model.RangeSet, but
    # with the 'context' removed. Eventually, we probably
    # want to change the tmtc one to use this class too.

    def __init__(
        self,
        watch: Optional[Tuple[float, float]] = None,
        warning: Optional[Tuple[float, float]] = None,
        distress: Optional[Tuple[float, float]] = None,
        critical: Optional[Tuple[float, float]] = None,
        severe: Optional[Tuple[float, float]] = None,
        min_violations: int = 1,
    ):
        """
        :param watch:
            Range expressed as a tuple ``(lo, hi)``
            where lo and hi are assumed exclusive.
        :param warning:
            Range expressed as a tuple ``(lo, hi)``
            where lo and hi are assumed exclusive.
        :param distress:
            Range expressed as a tuple ``(lo, hi)``
            where lo and hi are assumed exclusive.
        :param critical:
            Range expressed as a tuple ``(lo, hi)``
            where lo and hi are assumed exclusive.
        :param severe:
            Range expressed as a tuple ``(lo, hi)``
            where lo and hi are assumed exclusive.
        :param min_violations:
            Minimum violations before an alarm is
            generated.
        """
        self.watch = watch
        self.warning = warning
        self.distress = distress
        self.critical = critical
        self.severe = severe
        self.min_violations = min_violations



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/services/services.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/services/services.proto',
  package='yamcs.protobuf.services',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\rServicesProtoP\001',
  serialized_pb=b'\n&yamcs/protobuf/services/services.proto\x12\x17yamcs.protobuf.services\"\xb7\x01\n\x0bServiceInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x34\n\x05state\x18\x03 \x01(\x0e\x32%.yamcs.protobuf.services.ServiceState\x12\x11\n\tclassName\x18\x04 \x01(\t\x12\x11\n\tprocessor\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\x06 \x01(\t\x12\x14\n\x0c\x66\x61ilureCause\x18\x07 \x01(\t*\\\n\x0cServiceState\x12\x07\n\x03NEW\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08STOPPING\x10\x03\x12\x0e\n\nTERMINATED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x42%\n\x12org.yamcs.protobufB\rServicesProtoP\x01'
)

_SERVICESTATE = _descriptor.EnumDescriptor(
  name='ServiceState',
  full_name='yamcs.protobuf.services.ServiceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TERMINATED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=253,
  serialized_end=345,
)
_sym_db.RegisterEnumDescriptor(_SERVICESTATE)

ServiceState = enum_type_wrapper.EnumTypeWrapper(_SERVICESTATE)
NEW = 0
STARTING = 1
RUNNING = 2
STOPPING = 3
TERMINATED = 4
FAILED = 5



_SERVICEINFO = _descriptor.Descriptor(
  name='ServiceInfo',
  full_name='yamcs.protobuf.services.ServiceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.services.ServiceInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.services.ServiceInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.services.ServiceInfo.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='className', full_name='yamcs.protobuf.services.ServiceInfo.className', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.services.ServiceInfo.processor', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureMessage', full_name='yamcs.protobuf.services.ServiceInfo.failureMessage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureCause', full_name='yamcs.protobuf.services.ServiceInfo.failureCause', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=251,
)

_SERVICEINFO.fields_by_name['state'].enum_type = _SERVICESTATE
DESCRIPTOR.message_types_by_name['ServiceInfo'] = _SERVICEINFO
DESCRIPTOR.enum_types_by_name['ServiceState'] = _SERVICESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServiceInfo = _reflection.GeneratedProtocolMessageType('ServiceInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINFO,
  '__module__' : 'yamcs.protobuf.services.services_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.services.ServiceInfo)
  })
_sym_db.RegisterMessage(ServiceInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/archive/archive.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/archive/archive.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobuf',
  serialized_pb=b'\n$yamcs/protobuf/archive/archive.proto\x12\x16yamcs.protobuf.archive\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"\xc2\x01\n\x1cStreamParameterValuesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x03ids\x18\x04 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x0f\n\x07tmLinks\x18\x05 \x03(\t\"$\n\x12ParameterGroupInfo\x12\x0e\n\x06groups\x18\x02 \x03(\t\".\n\x1aListParameterGroupsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\xa6\x02\n\x1bListParameterHistoryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x10\n\x08norepeat\x18\x05 \x01(\x08\x12)\n\x05start\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05order\x18\x08 \x01(\t\x12\x12\n\nnorealtime\x18\t \x01(\x08\x12\x11\n\tprocessor\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x10\n\x08maxBytes\x18\r \x01(\x05\x12\x0c\n\x04next\x18\x0c \x01(\t\"s\n\x1cListParameterHistoryResponse\x12\x38\n\tparameter\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"\xfd\x01\n\x1aGetParameterSamplesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x12\n\nnorealtime\x18\x06 \x01(\x08\x12\x13\n\x0buseRawValue\x18\t \x01(\x08\x12\x0f\n\x07gapTime\x18\n \x01(\x04\x12\x11\n\tprocessor\x18\x07 \x01(\t\x12\x0e\n\x06source\x18\x08 \x01(\t\"\xd6\x02\n\x1c\x45xportParameterValuesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nparameters\x18\x04 \x03(\t\x12\x0c\n\x04list\x18\x0e \x01(\t\x12\x11\n\tnamespace\x18\x05 \x01(\t\x12\r\n\x05\x65xtra\x18\x06 \x03(\t\x12\x11\n\tdelimiter\x18\x07 \x01(\t\x12\x10\n\x08interval\x18\x08 \x01(\x05\x12\x19\n\x11preserveLastValue\x18\t \x01(\x08\x12\x0b\n\x03pos\x18\n \x01(\x03\x12\r\n\x05limit\x18\x0b \x01(\x05\x12\r\n\x05order\x18\x0c \x01(\t\x12\x10\n\x08\x66ilename\x18\r \x01(\t\x12\x0e\n\x06header\x18\x0f \x01(\t2\xb6\x07\n\x10StreamArchiveApi\x12\xa5\x01\n\x13ListParameterGroups\x12\x32.yamcs.protobuf.archive.ListParameterGroupsRequest\x1a*.yamcs.protobuf.archive.ParameterGroupInfo\".\x8a\x92\x03*\n(/api/archive/{instance}/parameter-groups\x12\xba\x01\n\x14ListParameterHistory\x12\x33.yamcs.protobuf.archive.ListParameterHistoryRequest\x1a\x34.yamcs.protobuf.archive.ListParameterHistoryResponse\"7\x8a\x92\x03\x33\n1/api/stream-archive/{instance}/parameters/{name*}\x12\xb4\x01\n\x15StreamParameterValues\x12\x34.yamcs.protobuf.archive.StreamParameterValuesRequest\x1a$.yamcs.protobuf.pvalue.ParameterData\"=\x8a\x92\x03\x39\x1a\x34/api/stream-archive/{instance}:streamParameterValues:\x01*0\x01\x12\xb5\x01\n\x13GetParameterSamples\x12\x32.yamcs.protobuf.archive.GetParameterSamplesRequest\x1a!.yamcs.protobuf.pvalue.TimeSeries\"G\x8a\x92\x03\x43\n9/api/stream-archive/{instance}/parameters/{name*}/samplesR\x06sample\x12\xcd\x01\n\x15\x45xportParameterValues\x12\x34.yamcs.protobuf.archive.ExportParameterValuesRequest\x1a\x13.yamcs.api.HttpBody\"g\x8a\x92\x03\x63\n-/api/archive/{instance}:exportParameterValuesZ2\x1a-/api/archive/{instance}:exportParameterValues:\x01*0\x01\x42\x14\n\x12org.yamcs.protobuf'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_STREAMPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='StreamParameterValuesRequest',
  full_name='yamcs.protobuf.archive.StreamParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.ids', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmLinks', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.tmLinks', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=411,
)


_PARAMETERGROUPINFO = _descriptor.Descriptor(
  name='ParameterGroupInfo',
  full_name='yamcs.protobuf.archive.ParameterGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='yamcs.protobuf.archive.ParameterGroupInfo.groups', index=0,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=449,
)


_LISTPARAMETERGROUPSREQUEST = _descriptor.Descriptor(
  name='ListParameterGroupsRequest',
  full_name='yamcs.protobuf.archive.ListParameterGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListParameterGroupsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=497,
)


_LISTPARAMETERHISTORYREQUEST = _descriptor.Descriptor(
  name='ListParameterHistoryRequest',
  full_name='yamcs.protobuf.archive.ListParameterHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.pos', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='norepeat', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.norepeat', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.start', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.stop', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.order', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='norealtime', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.norealtime', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.processor', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.source', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxBytes', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.maxBytes', index=11,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.next', index=12,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=794,
)


_LISTPARAMETERHISTORYRESPONSE = _descriptor.Descriptor(
  name='ListParameterHistoryResponse',
  full_name='yamcs.protobuf.archive.ListParameterHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.archive.ListParameterHistoryResponse.parameter', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.archive.ListParameterHistoryResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=911,
)


_GETPARAMETERSAMPLESREQUEST = _descriptor.Descriptor(
  name='GetParameterSamplesRequest',
  full_name='yamcs.protobuf.archive.GetParameterSamplesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.count', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='norealtime', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.norealtime', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='useRawValue', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.useRawValue', index=6,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gapTime', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.gapTime', index=7,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.processor', index=8,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.source', index=9,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=914,
  serialized_end=1167,
)


_EXPORTPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='ExportParameterValuesRequest',
  full_name='yamcs.protobuf.archive.ExportParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.parameters', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.list', index=4,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.namespace', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.extra', index=6,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delimiter', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.delimiter', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.interval', index=8,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preserveLastValue', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.preserveLastValue', index=9,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.pos', index=10,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.limit', index=11,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.order', index=12,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.filename', index=13,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='yamcs.protobuf.archive.ExportParameterValuesRequest.header', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1170,
  serialized_end=1512,
)

_STREAMPARAMETERVALUESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPARAMETERVALUESREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPARAMETERVALUESREQUEST.fields_by_name['ids'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_LISTPARAMETERHISTORYREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERHISTORYREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERHISTORYRESPONSE.fields_by_name['parameter'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_GETPARAMETERSAMPLESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETPARAMETERSAMPLESREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTPARAMETERVALUESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTPARAMETERVALUESREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamParameterValuesRequest'] = _STREAMPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['ParameterGroupInfo'] = _PARAMETERGROUPINFO
DESCRIPTOR.message_types_by_name['ListParameterGroupsRequest'] = _LISTPARAMETERGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListParameterHistoryRequest'] = _LISTPARAMETERHISTORYREQUEST
DESCRIPTOR.message_types_by_name['ListParameterHistoryResponse'] = _LISTPARAMETERHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['GetParameterSamplesRequest'] = _GETPARAMETERSAMPLESREQUEST
DESCRIPTOR.message_types_by_name['ExportParameterValuesRequest'] = _EXPORTPARAMETERVALUESREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamParameterValuesRequest = _reflection.GeneratedProtocolMessageType('StreamParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamParameterValuesRequest)
  })
_sym_db.RegisterMessage(StreamParameterValuesRequest)

ParameterGroupInfo = _reflection.GeneratedProtocolMessageType('ParameterGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERGROUPINFO,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ParameterGroupInfo)
  })
_sym_db.RegisterMessage(ParameterGroupInfo)

ListParameterGroupsRequest = _reflection.GeneratedProtocolMessageType('ListParameterGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERGROUPSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterGroupsRequest)
  })
_sym_db.RegisterMessage(ListParameterGroupsRequest)

ListParameterHistoryRequest = _reflection.GeneratedProtocolMessageType('ListParameterHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERHISTORYREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterHistoryRequest)
  })
_sym_db.RegisterMessage(ListParameterHistoryRequest)

ListParameterHistoryResponse = _reflection.GeneratedProtocolMessageType('ListParameterHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERHISTORYRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterHistoryResponse)
  })
_sym_db.RegisterMessage(ListParameterHistoryResponse)

GetParameterSamplesRequest = _reflection.GeneratedProtocolMessageType('GetParameterSamplesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERSAMPLESREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.GetParameterSamplesRequest)
  })
_sym_db.RegisterMessage(GetParameterSamplesRequest)

ExportParameterValuesRequest = _reflection.GeneratedProtocolMessageType('ExportParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ExportParameterValuesRequest)
  })
_sym_db.RegisterMessage(ExportParameterValuesRequest)


DESCRIPTOR._options = None

_STREAMARCHIVEAPI = _descriptor.ServiceDescriptor(
  name='StreamArchiveApi',
  full_name='yamcs.protobuf.archive.StreamArchiveApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1515,
  serialized_end=2465,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListParameterGroups',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListParameterGroups',
    index=0,
    containing_service=None,
    input_type=_LISTPARAMETERGROUPSREQUEST,
    output_type=_PARAMETERGROUPINFO,
    serialized_options=b'\212\222\003*\n(/api/archive/{instance}/parameter-groups',
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterHistory',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListParameterHistory',
    index=1,
    containing_service=None,
    input_type=_LISTPARAMETERHISTORYREQUEST,
    output_type=_LISTPARAMETERHISTORYRESPONSE,
    serialized_options=b'\212\222\0033\n1/api/stream-archive/{instance}/parameters/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='StreamParameterValues',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.StreamParameterValues',
    index=2,
    containing_service=None,
    input_type=_STREAMPARAMETERVALUESREQUEST,
    output_type=yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERDATA,
    serialized_options=b'\212\222\0039\0324/api/stream-archive/{instance}:streamParameterValues:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='GetParameterSamples',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.GetParameterSamples',
    index=3,
    containing_service=None,
    input_type=_GETPARAMETERSAMPLESREQUEST,
    output_type=yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._TIMESERIES,
    serialized_options=b'\212\222\003C\n9/api/stream-archive/{instance}/parameters/{name*}/samplesR\006sample',
  ),
  _descriptor.MethodDescriptor(
    name='ExportParameterValues',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ExportParameterValues',
    index=4,
    containing_service=None,
    input_type=_EXPORTPARAMETERVALUESREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\212\222\003c\n-/api/archive/{instance}:exportParameterValuesZ2\032-/api/archive/{instance}:exportParameterValues:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMARCHIVEAPI)

DESCRIPTOR.services_by_name['StreamArchiveApi'] = _STREAMARCHIVEAPI

# @@protoc_insertion_point(module_scope)



from yamcs import clientversion  # noqa
from yamcs.archive.client import *  # noqa
from yamcs.archive.model import *  # noqa
from yamcs.client.activities import *  # noqa
from yamcs.client.core import *  # noqa
from yamcs.core import GLOBAL_INSTANCE  # noqa
from yamcs.core.auth import *  # noqa
from yamcs.core.context import *  # noqa
from yamcs.core.exceptions import *  # noqa
from yamcs.core.futures import *  # noqa
from yamcs.core.helpers import *  # noqa
from yamcs.core.pagination import *  # noqa
from yamcs.core.subscriptions import *  # noqa
from yamcs.filetransfer.client import *  # noqa
from yamcs.filetransfer.model import *  # noqa
from yamcs.link.client import *  # noqa
from yamcs.link.model import *  # noqa
from yamcs.mdb.client import *  # noqa
from yamcs.mdb.model import *  # noqa
from yamcs.model import *  # noqa
from yamcs.storage.client import *  # noqa
from yamcs.storage.model import *  # noqa
from yamcs.tco.client import *  # noqa
from yamcs.tco.model import *  # noqa
from yamcs.timeline.client import *  # noqa
from yamcs.timeline.model import *  # noqa
from yamcs.tmtc.client import *  # noqa
from yamcs.tmtc.model import *  # noqa

"""
Migration in process:

All files should eventually be available from within yamcs.client package,
following a lengthy deprecation process.

(excluding protobuf classes, which we could move elsewhere).

As a first step, we make everything directly available from yamcs.client.
(next step will be to update the examples)
"""
